@@ -69,7 +69,8 @@ func (gc *globCache) GetGlob(pattern string) (glob.Glob, error) {
 	eg = globErr{
 		globDecorator{
 			g:         g,
-			isWindows: gc.isWindows},
+			isWindows: gc.isWindows,
+		},
 		err,
 	}
 
@@ -121,15 +122,6 @@ func (g globDecorator) Match(s string) bool {
 	return g.g.Match(s)
 }
 
-type globDecoratorDouble struct {
-	lowerCase    glob.Glob
-	originalCase glob.Glob
-}
-
-func (g globDecoratorDouble) Match(s string) bool {
-	return g.lowerCase.Match(s) || g.originalCase.Match(s)
-}
-
 func GetGlob(pattern string) (glob.Glob, error) {
 	return defaultGlobCache.GetGlob(pattern)
 }
@@ -174,7 +166,7 @@ func FilterGlobParts(a []string) []string {
 
 // HasGlobChar returns whether s contains any glob wildcards.
 func HasGlobChar(s string) bool {
-	for i := 0; i < len(s); i++ {
+	for i := range len(s) {
 		if syntax.Special(s[i]) {
 			return true
 		}
